@@ -2,14 +2,19 @@ import logging
 
 from django.contrib.gis.db.backends.postgis.base import \
     DatabaseWrapper as PostgisDBWrapper
-from django.db import ProgrammingError
 
+from django.db import ProgrammingError
+from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
+
+from . import base_impl
 from .schema import TimescaleSchemaEditor
 
+
 logger = logging.getLogger(__name__)
 
 
-class DatabaseWrapper(PostgisDBWrapper):
+class DatabaseWrapper(base_impl.backend()):
     SchemaEditorClass = TimescaleSchemaEditor
 
     def prepare_database(self):
@@ -29,4 +34,4 @@ class DatabaseWrapper(PostgisDBWrapper):
                     'to the database as a superuser '
                     'or add the extension manually.',
                     exc_info=True
-                )
\ No newline at end of file
+                )
